@@ -34,6 +34,8 @@
 #include "samplv1_fx.h"
 #include "samplv1_reverb.h"
 
+#include "samplv1_pshifter.h"
+
 #include "samplv1_config.h"
 #include "samplv1_controls.h"
 #include "samplv1_programs.h"
@@ -62,8 +64,6 @@ const uint8_t MAX_NOTES   = 128;
 const float MIN_ENV_MSECS = 0.5f;		// min 500 usec per stage
 const float MAX_ENV_MSECS = 5000.0f;	// max 5 sec per stage (default)
 
-const float DETUNE_SCALE  = 0.5f;
-const float PHASE_SCALE   = 0.5f;
 const float OCTAVE_SCALE  = 12.0f;
 const float TUNING_SCALE  = 1.0f;
 const float SWEEP_SCALE   = 0.5f;
@@ -1054,8 +1054,9 @@ public:
 	void setSampleRate(float srate);
 	float sampleRate() const;
 
-	void setSampleFile(const char *pszSampleFile);
+	void setSampleFile(const char *pszSampleFile, uint16_t otabs);
 	const char *sampleFile() const;
+	uint16_t octaves() const;
 
 	void setBufferSize(uint32_t nsize);
 	uint32_t bufferSize() const;
@@ -1245,7 +1246,8 @@ samplv1_voice::samplv1_voice ( samplv1_impl *pImpl ) :
 samplv1_impl::samplv1_impl (
 	samplv1 *pSampl, uint16_t nchannels, float srate )
 		: gen1_sample(srate), m_controls(pSampl), m_programs(pSampl),
-			m_midi_in(pSampl), m_bpm(180.0f), m_gen1(pSampl), m_running(false)
+			m_midi_in(pSampl), m_bpm(180.0f), m_gen1(pSampl),
+			m_nvoices(0), m_running(false)
 {
 	// null sample.
 	m_gen1.sample0 = 0.0f;
@@ -1283,6 +1285,10 @@ samplv1_impl::samplv1_impl (
 	// compressors none yet
 	m_comp = nullptr;
 
+	// Pitch-shifting support...
+	samplv1_pshifter::setDefaultType(
+		samplv1_pshifter::Type(m_config.iPitchShiftType));
+
 	// Micro-tuning support, if any...
 	resetTuning();
 
@@ -1315,7 +1321,7 @@ samplv1_impl::~samplv1_impl (void)
 #endif
 
 	// deallocate sample filenames
-	setSampleFile(0);
+	setSampleFile(nullptr, 0);
 
 	// deallocate voice pool.
 	for (int i = 0; i < MAX_VOICES; ++i)
@@ -1466,15 +1472,15 @@ void samplv1_impl::updateEnvTimes (void)
 }
 
 
-void samplv1_impl::setSampleFile ( const char *pszSampleFile )
+void samplv1_impl::setSampleFile ( const char *pszSampleFile, uint16_t otabs )
 {
 	reset();
 
-	gen1_sample.close();
-
 	if (pszSampleFile) {
 		m_gen1.sample0 = *m_gen1.sample;
-		gen1_sample.open(pszSampleFile, samplv1_freq(m_gen1.sample0));
+		gen1_sample.open(pszSampleFile, samplv1_freq(m_gen1.sample0), otabs);
+	} else {
+		gen1_sample.close();
 	}
 }
 
@@ -1485,6 +1491,12 @@ const char *samplv1_impl::sampleFile (void) const
 }
 
 
+uint16_t samplv1_impl::octaves (void) const
+{
+	return gen1_sample.otabs();
+}
+
+
 void samplv1_impl::setParamPort ( samplv1::ParamIndex index, float *pfParam )
 {
 	static float s_fDummy = 0.0f;
@@ -1726,13 +1738,13 @@ void samplv1_impl::process_midi ( uint8_t *data, uint32_t size )
 				pv->dca1_pre.reset(
 					m_def.pressure.value_ptr(),
 					&m_ctl1.pressure, &pv->pre);
-				// generate
-				pv->gen1.start();
 				// frequencies
 				const float gen1_tuning
 					= *m_gen1.octave * OCTAVE_SCALE
 					+ *m_gen1.tuning * TUNING_SCALE;
 				pv->gen1_freq = m_freqs[key] * samplv1_freq2(gen1_tuning);
+				// generator
+				pv->gen1.start(pv->gen1_freq);
 				// filters
 				const int dcf1_type = int(*m_dcf1.type);
 				pv->dcf11.reset(samplv1_filter1::Type(dcf1_type));
@@ -1759,6 +1771,8 @@ void samplv1_impl::process_midi ( uint8_t *data, uint32_t size )
 					m_dca1.env.start(&pv->dca1_env);
 				else
 					m_dca1.env.idle(&pv->dca1_env);
+				if (gen1_sample.isLoop())
+					pv->gen1.setLoop(*m_dca1.enabled > 0.0f);
 				// lfos
 				const float lfo1_pshift
 					= (m_lfo1.psync ? m_lfo1.psync->lfo1.pshift() : 0.0f);
@@ -1808,7 +1822,7 @@ void samplv1_impl::process_midi ( uint8_t *data, uint32_t size )
 						m_lfo1.env.restart(&pv->lfo1_env, legato);
 						m_dca1.env.restart(&pv->dca1_env, legato);
 						pv->gen1.setLoop(*m_gen1.loop > 0.0f);
-						if (!legato) pv->gen1.start();
+						if (!legato) pv->gen1.start(pv->gen1_freq);
 						m_notes[pv->note] = pv;
 					}
 				}
@@ -2567,9 +2581,9 @@ float samplv1::sampleRate (void) const
 }
 
 
-void samplv1::setSampleFile ( const char *pszSampleFile, bool bSync )
+void samplv1::setSampleFile ( const char *pszSampleFile, uint16_t iOctaves, bool bSync )
 {
-	m_pImpl->setSampleFile(pszSampleFile);
+	m_pImpl->setSampleFile(pszSampleFile, iOctaves);
 
 	if (bSync) updateSample();
 }
@@ -2581,6 +2595,12 @@ const char *samplv1::sampleFile (void) const
 }
 
 
+uint16_t samplv1::octaves (void) const
+{
+	return m_pImpl->octaves();
+}
+
+
 samplv1_sample *samplv1::sample (void) const
 {
 	return &(m_pImpl->gen1_sample);
