@@ -158,7 +158,7 @@ static void samplv1_jack_session_event (
 // samplv1_jack - impl.
 //
 
-samplv1_jack::samplv1_jack (void) : samplv1(2)
+samplv1_jack::samplv1_jack (const char *client_name) : samplv1(2)
 {
 	m_client = nullptr;
 
@@ -186,7 +186,7 @@ samplv1_jack::samplv1_jack (void) : samplv1(2)
 	samplv1::programs()->enabled(true);
 	samplv1::controls()->enabled(true);
 
-	open(SAMPLV1_TITLE);
+	open(client_name);
 	activate();
 }
 
@@ -288,7 +288,7 @@ int samplv1_jack::process ( jack_nframes_t nframes )
 }
 
 
-void samplv1_jack::open ( const char *client_id )
+void samplv1_jack::open ( const char *client_name )
 {
 	// init param ports
 	for (uint32_t i = 0; i < samplv1::NUM_PARAMS; ++i) {
@@ -298,7 +298,7 @@ void samplv1_jack::open ( const char *client_id )
 	}
 
 	// open client
-	m_client = ::jack_client_open(client_id, JackNullOption, nullptr);
+	m_client = ::jack_client_open(client_name, JackNullOption, nullptr);
 	if (m_client == nullptr)
 		return;
 
@@ -341,7 +341,7 @@ void samplv1_jack::open ( const char *client_id )
 	m_alsa_thread  = nullptr;
 	// open alsa sequencer client...
 	if (snd_seq_open(&m_alsa_seq, "hw", SND_SEQ_OPEN_INPUT, 0) >= 0) {
-		snd_seq_set_client_name(m_alsa_seq, client_id);
+		snd_seq_set_client_name(m_alsa_seq, client_name);
 	//	m_alsa_client = snd_seq_client_id(m_alsa_seq);
 		m_alsa_port = snd_seq_create_simple_port(m_alsa_seq, "in",
 			SND_SEQ_PORT_CAP_WRITE | SND_SEQ_PORT_CAP_SUBS_WRITE,
@@ -723,7 +723,7 @@ static void samplv1_sigterm_handler ( int /*signo*/ )
 // Constructor.
 samplv1_jack_application::samplv1_jack_application ( int& argc, char **argv )
 	: QObject(nullptr), m_pApp(nullptr), m_bGui(true),
-		m_pSampl(nullptr), m_pWidget(nullptr)
+		m_sClientName(SAMPLV1_TITLE), m_pSampl(nullptr), m_pWidget(nullptr)
 	  #ifdef CONFIG_NSM
 		, m_pNsmClient(nullptr)
 	  #endif
@@ -732,10 +732,8 @@ samplv1_jack_application::samplv1_jack_application ( int& argc, char **argv )
 	m_bGui = (::getenv("DISPLAY") != 0);
 #endif
 	for (int i = 1; i < argc; ++i) {
-		const QString& sArg = QString::fromLocal8Bit(argv[i]);
-		if (sArg[0] != '-')
-			m_presets.append(sArg);
-		else
+		const QString& sArg
+			= QString::fromLocal8Bit(argv[i]);
 		if (sArg == "-g" || sArg == "--no-gui")
 			m_bGui = false;
 	}
@@ -817,17 +815,42 @@ samplv1_jack_application::~samplv1_jack_application (void)
 bool samplv1_jack_application::parse_args (void)
 {
 	QTextStream out(stderr);
-
 	const QStringList& args = m_pApp->arguments();
-	QStringListIterator iter(args);
-	while (iter.hasNext()) {
-		const QString& sArg = iter.next();
+	const int argc = args.count();
+
+	for (int i = 1; i < argc; ++i) {
+
+		QString sArg = args.at(i);
+
+		QString sVal;
+		const int iEqual = sArg.indexOf('=');
+		if (iEqual >= 0) {
+			sVal = sArg.right(sArg.length() - iEqual - 1);
+			sArg = sArg.left(iEqual);
+		}
+		else if (i < argc - 1) {
+			sVal = args.at(i + 1);
+			if (sVal.at(0) == '-')
+				sVal.clear();
+		}
+
+		if (sArg == "-n" || sArg == "--client-name") {
+			if (sVal.isNull()) {
+				out << QObject::tr("Option -n requires an argument (client-name).\n\n");
+				return false;
+			}
+			m_sClientName = sVal;
+			if (iEqual < 0)
+				++i;
+		}
+		else
 		if (sArg == "-h" || sArg == "--help") {
 			out << QObject::tr(
 				"Usage: %1 [options] [preset-file]\n\n"
 				SAMPLV1_TITLE " - " SAMPLV1_SUBTITLE "\n\n"
 				"Options:\n\n"
 				"  -g, --no-gui\n\tDisable the graphical user interface (GUI)\n\n"
+				"  -n, --client-name=[label]\n\tSet the JACK client name (default: samplv1)\n\n"
 				"  -h, --help\n\tShow help about command line options\n\n"
 				"  -v, --version\n\tShow version information\n\n")
 				.arg(args.at(0));
@@ -842,6 +865,11 @@ bool samplv1_jack_application::parse_args (void)
 				.arg(CONFIG_BUILD_VERSION);
 			return false;
 		}
+		else {
+			// If we don't have one by now,
+			// this will be the startup preset file...
+			m_presets.append(sArg);
+		}
 	}
 
 	return true;
@@ -863,7 +891,12 @@ bool samplv1_jack_application::setup (void)
 		SIGNAL(shutdown_signal()),
 		SLOT(shutdown_slot()));
 
-	m_pSampl = new samplv1_jack();
+	const QByteArray aClientName
+		= m_sClientName.toLocal8Bit();
+	const char *client_name
+		= aClientName.constData();
+
+	m_pSampl = new samplv1_jack(client_name);
 
 	if (m_bGui) {
 		m_pWidget = new samplv1widget_jack(m_pSampl);
@@ -898,7 +931,7 @@ bool samplv1_jack_application::setup (void)
 		QString caps(":switch:dirty:");
 		if (m_bGui)
 			caps += "optional-gui:";
-		m_pNsmClient->announce(SAMPLV1_TITLE, caps.toLatin1().constData());
+		m_pNsmClient->announce(SAMPLV1_TITLE, caps.toLocal8Bit().constData());
 		if (m_pWidget)
 			m_pWidget->setNsmClient(m_pNsmClient);
 	}
@@ -938,11 +971,11 @@ void samplv1_jack_application::openSession (void)
 	m_pSampl->deactivate();
 	m_pSampl->close();
 
-	const QString& client_id = m_pNsmClient->client_id();
+	const QString& client_name = m_pNsmClient->client_name();
 	const QString& path_name = m_pNsmClient->path_name();
 	const QString& display_name = m_pNsmClient->display_name();
 
-	m_pSampl->open(client_id.toUtf8().constData());
+	m_pSampl->open(client_name.toUtf8().constData());
 	m_pSampl->activate();
 
 	const QDir dir(path_name);
@@ -983,7 +1016,7 @@ void samplv1_jack_application::saveSession (void)
 	qDebug("samplv1_jack::saveSession()");
 #endif
 
-//	const QString& client_id = m_pNsmClient->client_id();
+//	const QString& client_name = m_pNsmClient->client_name();
 	const QString& path_name = m_pNsmClient->path_name();
 //	const QString& display_name = m_pNsmClient->display_name();
 //	const QFileInfo fi(path_name, display_name + '.' + SAMPLV1_TITLE);
