@@ -43,13 +43,13 @@ class samplv1_jack : public samplv1
 {
 public:
 
-	samplv1_jack();
+	samplv1_jack(const char *client_name);
 
 	~samplv1_jack();
 
 	jack_client_t *client() const;
 
-	void open(const char *client_id);
+	void open(const char *client_name);
 	void close();
 
 	void activate();
@@ -189,6 +189,7 @@ private:
 	QCoreApplication *m_pApp;
 	bool m_bGui;
 
+	QString m_sClientName;
 	QStringList m_presets;
 
 	samplv1_jack *m_pSampl;
