@@ -1234,7 +1234,7 @@ void samplv1widget_palette::ColorButton::paintEvent ( QPaintEvent *event )
 	QPushButton::paintEvent(event);
 
 	QStyleOptionButton opt;
-	opt.init(this);
+	opt.initFrom(this);
 
 	const QRect& rect
 		= style()->subElementRect(QStyle::SE_PushButtonContents, &opt, this);
